import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface BackupPlanConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#name BackupPlan#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#tags BackupPlan#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#tags_all BackupPlan#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * advanced_backup_setting block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#advanced_backup_setting BackupPlan#advanced_backup_setting}
     *
     * @stability stable
     */
    readonly advancedBackupSetting?: BackupPlanAdvancedBackupSetting[];
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#rule BackupPlan#rule}
     *
     * @stability stable
     */
    readonly rule: BackupPlanRule[];
}
/**
 * @stability stable
 */
export interface BackupPlanAdvancedBackupSetting {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#backup_options BackupPlan#backup_options}.
     *
     * @stability stable
     */
    readonly backupOptions: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#resource_type BackupPlan#resource_type}.
     *
     * @stability stable
     */
    readonly resourceType: string;
}
/**
 * @stability stable
 */
export interface BackupPlanRuleCopyActionLifecycle {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#cold_storage_after BackupPlan#cold_storage_after}.
     *
     * @stability stable
     */
    readonly coldStorageAfter?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#delete_after BackupPlan#delete_after}.
     *
     * @stability stable
     */
    readonly deleteAfter?: number;
}
/**
 * @stability stable
 */
export interface BackupPlanRuleCopyAction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#destination_vault_arn BackupPlan#destination_vault_arn}.
     *
     * @stability stable
     */
    readonly destinationVaultArn: string;
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#lifecycle BackupPlan#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: BackupPlanRuleCopyActionLifecycle[];
}
/**
 * @stability stable
 */
export interface BackupPlanRuleLifecycle {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#cold_storage_after BackupPlan#cold_storage_after}.
     *
     * @stability stable
     */
    readonly coldStorageAfter?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#delete_after BackupPlan#delete_after}.
     *
     * @stability stable
     */
    readonly deleteAfter?: number;
}
/**
 * @stability stable
 */
export interface BackupPlanRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#completion_window BackupPlan#completion_window}.
     *
     * @stability stable
     */
    readonly completionWindow?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#enable_continuous_backup BackupPlan#enable_continuous_backup}.
     *
     * @stability stable
     */
    readonly enableContinuousBackup?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#recovery_point_tags BackupPlan#recovery_point_tags}.
     *
     * @stability stable
     */
    readonly recoveryPointTags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#rule_name BackupPlan#rule_name}.
     *
     * @stability stable
     */
    readonly ruleName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#schedule BackupPlan#schedule}.
     *
     * @stability stable
     */
    readonly schedule?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#start_window BackupPlan#start_window}.
     *
     * @stability stable
     */
    readonly startWindow?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#target_vault_name BackupPlan#target_vault_name}.
     *
     * @stability stable
     */
    readonly targetVaultName: string;
    /**
     * copy_action block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#copy_action BackupPlan#copy_action}
     *
     * @stability stable
     */
    readonly copyAction?: BackupPlanRuleCopyAction[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#lifecycle BackupPlan#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: BackupPlanRuleLifecycle[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html aws_backup_plan}.
 *
 * @stability stable
 */
export declare class BackupPlan extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html aws_backup_plan} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: BackupPlanConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get version(): string;
    private _advancedBackupSetting?;
    /**
     * @stability stable
     */
    get advancedBackupSetting(): BackupPlanAdvancedBackupSetting[];
    /**
     * @stability stable
     */
    set advancedBackupSetting(value: BackupPlanAdvancedBackupSetting[]);
    /**
     * @stability stable
     */
    resetAdvancedBackupSetting(): void;
    /**
     * @stability stable
     */
    get advancedBackupSettingInput(): BackupPlanAdvancedBackupSetting[] | undefined;
    private _rule;
    /**
     * @stability stable
     */
    get rule(): BackupPlanRule[];
    /**
     * @stability stable
     */
    set rule(value: BackupPlanRule[]);
    /**
     * @stability stable
     */
    get ruleInput(): BackupPlanRule[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
