import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SignerSigningJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#ignore_signing_job_failure SignerSigningJob#ignore_signing_job_failure}.
     *
     * @stability stable
     */
    readonly ignoreSigningJobFailure?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#profile_name SignerSigningJob#profile_name}.
     *
     * @stability stable
     */
    readonly profileName: string;
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#destination SignerSigningJob#destination}
     *
     * @stability stable
     */
    readonly destination: SignerSigningJobDestination[];
    /**
     * source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#source SignerSigningJob#source}
     *
     * @stability stable
     */
    readonly source: SignerSigningJobSource[];
}
/**
 * @stability stable
 */
export declare class SignerSigningJobRevocationRecord extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get reason(): string;
    /**
     * @stability stable
     */
    get revokedAt(): string;
    /**
     * @stability stable
     */
    get revokedBy(): string;
}
/**
 * @stability stable
 */
export declare class SignerSigningJobSignedObjectS3 extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    get key(): string;
}
/**
 * @stability stable
 */
export declare class SignerSigningJobSignedObject extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get s3(): any;
}
/**
 * @stability stable
 */
export interface SignerSigningJobDestinationS3 {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#bucket SignerSigningJob#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#prefix SignerSigningJob#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
/**
 * @stability stable
 */
export interface SignerSigningJobDestination {
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#s3 SignerSigningJob#s3}
     *
     * @stability stable
     */
    readonly s3: SignerSigningJobDestinationS3[];
}
/**
 * @stability stable
 */
export interface SignerSigningJobSourceS3 {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#bucket SignerSigningJob#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#key SignerSigningJob#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#version SignerSigningJob#version}.
     *
     * @stability stable
     */
    readonly version: string;
}
/**
 * @stability stable
 */
export interface SignerSigningJobSource {
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html#s3 SignerSigningJob#s3}
     *
     * @stability stable
     */
    readonly s3: SignerSigningJobSourceS3[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html aws_signer_signing_job}.
 *
 * @stability stable
 */
export declare class SignerSigningJob extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job.html aws_signer_signing_job} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SignerSigningJobConfig);
    /**
     * @stability stable
     */
    get completedAt(): string;
    /**
     * @stability stable
     */
    get createdAt(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ignoreSigningJobFailure?;
    /**
     * @stability stable
     */
    get ignoreSigningJobFailure(): boolean;
    /**
     * @stability stable
     */
    set ignoreSigningJobFailure(value: boolean);
    /**
     * @stability stable
     */
    resetIgnoreSigningJobFailure(): void;
    /**
     * @stability stable
     */
    get ignoreSigningJobFailureInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get jobId(): string;
    /**
     * @stability stable
     */
    get jobInvoker(): string;
    /**
     * @stability stable
     */
    get jobOwner(): string;
    /**
     * @stability stable
     */
    get platformDisplayName(): string;
    /**
     * @stability stable
     */
    get platformId(): string;
    private _profileName;
    /**
     * @stability stable
     */
    get profileName(): string;
    /**
     * @stability stable
     */
    set profileName(value: string);
    /**
     * @stability stable
     */
    get profileNameInput(): string;
    /**
     * @stability stable
     */
    get profileVersion(): string;
    /**
     * @stability stable
     */
    get requestedBy(): string;
    /**
     * @stability stable
     */
    revocationRecord(index: string): SignerSigningJobRevocationRecord;
    /**
     * @stability stable
     */
    get signatureExpiresAt(): string;
    /**
     * @stability stable
     */
    signedObject(index: string): SignerSigningJobSignedObject;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    get statusReason(): string;
    private _destination;
    /**
     * @stability stable
     */
    get destination(): SignerSigningJobDestination[];
    /**
     * @stability stable
     */
    set destination(value: SignerSigningJobDestination[]);
    /**
     * @stability stable
     */
    get destinationInput(): SignerSigningJobDestination[];
    private _source;
    /**
     * @stability stable
     */
    get source(): SignerSigningJobSource[];
    /**
     * @stability stable
     */
    set source(value: SignerSigningJobSource[]);
    /**
     * @stability stable
     */
    get sourceInput(): SignerSigningJobSource[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
