import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface VpcPeeringConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#auto_accept VpcPeeringConnection#auto_accept}.
     *
     * @stability stable
     */
    readonly autoAccept?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_owner_id VpcPeeringConnection#peer_owner_id}.
     *
     * @stability stable
     */
    readonly peerOwnerId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_region VpcPeeringConnection#peer_region}.
     *
     * @stability stable
     */
    readonly peerRegion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_vpc_id VpcPeeringConnection#peer_vpc_id}.
     *
     * @stability stable
     */
    readonly peerVpcId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#tags VpcPeeringConnection#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#tags_all VpcPeeringConnection#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#vpc_id VpcPeeringConnection#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId: string;
    /**
     * accepter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#accepter VpcPeeringConnection#accepter}
     *
     * @stability stable
     */
    readonly accepter?: VpcPeeringConnectionAccepter[];
    /**
     * requester block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#requester VpcPeeringConnection#requester}
     *
     * @stability stable
     */
    readonly requester?: VpcPeeringConnectionRequester[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#timeouts VpcPeeringConnection#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: VpcPeeringConnectionTimeouts;
}
/**
 * @stability stable
 */
export interface VpcPeeringConnectionAccepter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_classic_link_to_remote_vpc VpcPeeringConnection#allow_classic_link_to_remote_vpc}.
     *
     * @stability stable
     */
    readonly allowClassicLinkToRemoteVpc?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_remote_vpc_dns_resolution VpcPeeringConnection#allow_remote_vpc_dns_resolution}.
     *
     * @stability stable
     */
    readonly allowRemoteVpcDnsResolution?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_vpc_to_remote_classic_link VpcPeeringConnection#allow_vpc_to_remote_classic_link}.
     *
     * @stability stable
     */
    readonly allowVpcToRemoteClassicLink?: boolean;
}
/**
 * @stability stable
 */
export interface VpcPeeringConnectionRequester {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_classic_link_to_remote_vpc VpcPeeringConnection#allow_classic_link_to_remote_vpc}.
     *
     * @stability stable
     */
    readonly allowClassicLinkToRemoteVpc?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_remote_vpc_dns_resolution VpcPeeringConnection#allow_remote_vpc_dns_resolution}.
     *
     * @stability stable
     */
    readonly allowRemoteVpcDnsResolution?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_vpc_to_remote_classic_link VpcPeeringConnection#allow_vpc_to_remote_classic_link}.
     *
     * @stability stable
     */
    readonly allowVpcToRemoteClassicLink?: boolean;
}
/**
 * @stability stable
 */
export interface VpcPeeringConnectionTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#create VpcPeeringConnection#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#delete VpcPeeringConnection#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#update VpcPeeringConnection#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html aws_vpc_peering_connection}.
 *
 * @stability stable
 */
export declare class VpcPeeringConnection extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html aws_vpc_peering_connection} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: VpcPeeringConnectionConfig);
    /**
     * @stability stable
     */
    get acceptStatus(): string;
    private _autoAccept?;
    /**
     * @stability stable
     */
    get autoAccept(): boolean;
    /**
     * @stability stable
     */
    set autoAccept(value: boolean);
    /**
     * @stability stable
     */
    resetAutoAccept(): void;
    /**
     * @stability stable
     */
    get autoAcceptInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _peerOwnerId?;
    /**
     * @stability stable
     */
    get peerOwnerId(): string;
    /**
     * @stability stable
     */
    set peerOwnerId(value: string);
    /**
     * @stability stable
     */
    resetPeerOwnerId(): void;
    /**
     * @stability stable
     */
    get peerOwnerIdInput(): string | undefined;
    private _peerRegion?;
    /**
     * @stability stable
     */
    get peerRegion(): string;
    /**
     * @stability stable
     */
    set peerRegion(value: string);
    /**
     * @stability stable
     */
    resetPeerRegion(): void;
    /**
     * @stability stable
     */
    get peerRegionInput(): string | undefined;
    private _peerVpcId;
    /**
     * @stability stable
     */
    get peerVpcId(): string;
    /**
     * @stability stable
     */
    set peerVpcId(value: string);
    /**
     * @stability stable
     */
    get peerVpcIdInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _vpcId;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    set vpcId(value: string);
    /**
     * @stability stable
     */
    get vpcIdInput(): string;
    private _accepter?;
    /**
     * @stability stable
     */
    get accepter(): VpcPeeringConnectionAccepter[];
    /**
     * @stability stable
     */
    set accepter(value: VpcPeeringConnectionAccepter[]);
    /**
     * @stability stable
     */
    resetAccepter(): void;
    /**
     * @stability stable
     */
    get accepterInput(): VpcPeeringConnectionAccepter[] | undefined;
    private _requester?;
    /**
     * @stability stable
     */
    get requester(): VpcPeeringConnectionRequester[];
    /**
     * @stability stable
     */
    set requester(value: VpcPeeringConnectionRequester[]);
    /**
     * @stability stable
     */
    resetRequester(): void;
    /**
     * @stability stable
     */
    get requesterInput(): VpcPeeringConnectionRequester[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): VpcPeeringConnectionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: VpcPeeringConnectionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): VpcPeeringConnectionTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
